@@ -29,7 +29,7 @@
 #include <string.h>
 #include <cairo/cairo.h>
 #include <pango/pangocairo.h>
-#include <GL/gl.h>
+//#include <GLES2/gl2.h>
 #include <glib-object.h>
 
 #include "clutter-gesture.h"
