@@ -26,7 +26,7 @@
 #include <errno.h>
 #include <cairo/cairo.h>
 #include <pango/pangocairo.h>
-#include <GL/gl.h>
+//#include <GLES2/gl2.h>
 #include "engine.h"
 #include "../clutter-gesture/clutter-gesture.h"
 #include "stroke.h"
